@@ -1,4 +1,4 @@
-#' A cluster future is a future whose value will be resolved asynchroneously in a parallel process
+#' A cluster future is a future whose value will be resolved asynchronously in a parallel process
 #'
 #' @inheritParams MultiprocessFuture-class
 #' @param globals (optional) a logical, a character vector,
@@ -85,6 +85,8 @@ ClusterFuture <- function(expr=NULL, envir=parent.frame(), substitute=FALSE, loc
 #' @importFrom parallel clusterCall clusterExport
 #' @export
 run.ClusterFuture <- function(future, ...) {
+  debug <- getOption("future.debug", FALSE)
+  
   if (future$state != 'created') {
     stop("A future can only be launched once.")
   }
@@ -104,9 +106,7 @@ run.ClusterFuture <- function(future, ...) {
 
   ## Next available cluster node
   node <- requestNode(await=function() {
-    mdebug("Waiting for free cluster node ...")
     FutureRegistry(reg, action="collect-first")
-    mdebug("Waiting for free cluster node ... DONE")
   }, workers=workers)
   future$node <- node
 
@@ -119,10 +119,10 @@ run.ClusterFuture <- function(future, ...) {
   ## library path used by covr.  We here add that path iff
   ## covr is being used. /HB 2016-01-15
   if (is.element("covr", loadedNamespaces())) {
-    mdebug("covr::package_coverage() workaround ...")
+    if (debug) mdebug("covr::package_coverage() workaround ...")
     libPath <- .libPaths()[1]
     clusterCall(cl, fun=function() .libPaths(c(libPath, .libPaths())))
-    mdebug("covr::package_coverage() workaround ... DONE")
+    if (debug) mdebug("covr::package_coverage() workaround ... DONE")
   }
 
 
@@ -138,31 +138,41 @@ run.ClusterFuture <- function(future, ...) {
   ## (ii) Attach packages that needs to be attached
   packages <- future$packages
   if (length(packages) > 0) {
-    mdebug("Attaching %d packages (%s) on cluster node #%d ...",
-                    length(packages), hpaste(sQuote(packages)), node)
+    if (debug) mdebug("Attaching %d packages (%s) on cluster node #%d ...",
+                      length(packages), hpaste(sQuote(packages)), node)
 
     clusterCall(cl, fun=requirePackages, packages)
 
-    mdebug("Attaching %d packages (%s) on cluster node #%d ... DONE",
-                    length(packages), hpaste(sQuote(packages)), node)
+    if (debug) mdebug("Attaching %d packages (%s) on cluster node #%d ... DONE",
+                      length(packages), hpaste(sQuote(packages)), node)
   }
 
 
   ## (iii) Export globals
   globals <- future$globals
   if (length(globals) > 0) {
+    if (debug) {
+      total_size <- asIEC(objectSize(globals))
+      mdebug("Exporting %d global objects (%s) to cluster node #%d ...", length(globals), total_size, node)
+    }
     for (name in names(globals)) {
       ## For instance sendData.SOCKnode(...) may generate warnings
       ## on packages not being available after serialization, e.g.
       ##  In serialize(data, node$con) :
       ## package:future' may not be available when loading
       ## Here we'll suppress any such warnings.
-      mdebug("Exported %s to cluster node #%d ...", sQuote(name), node)
+      value <- globals[[name]]
+      if (debug) {
+        size <- asIEC(objectSize(value))
+        mdebug("Exporting %s (%s) to cluster node #%d ...", sQuote(name), size, node)
+      }
       suppressWarnings({
-        clusterCall(cl, fun=gassign, name, globals[[name]])
+        clusterCall(cl, fun=gassign, name, value)
       })
-      mdebug("Exported %s to cluster node #%d ... DONE", sQuote(name), node)
+      if (debug) mdebug("Exporting %s (%s) to cluster node #%d ... DONE", sQuote(name), size, node)
+      value <- NULL
     }
+    if (debug) mdebug("Exporting %d global objects (%s) to cluster node #%d ... DONE", length(globals), total_size, node)
   }
   ## Not needed anymore
   globals <- NULL
@@ -301,44 +311,52 @@ value.ClusterFuture <- function(future, ...) {
 }
 
 
-requestNode <- function(await, workers, times=getOption("future.wait.times", 600L), delta=getOption("future.wait.interval", 0.001), alpha=getOption("future.wait.alpha", 1.01)) {
-  stopifnot(is.function(await))
+requestNode <- function(await, workers, timeout = getOption("future.wait.timeout", 30*24*60*60), delta=getOption("future.wait.interval", 0.2), alpha=getOption("future.wait.alpha", 1.01)) {
   stopifnot(inherits(workers, "cluster"))
-  times <- as.integer(times)
-  stopifnot(is.finite(times), times > 0)
+  stopifnot(is.function(await))
+  stopifnot(is.finite(timeout), timeout >= 0)
   stopifnot(is.finite(alpha), alpha > 0)
 
   ## Maximum number of nodes available
   total <- length(workers)
 
   ## FutureRegistry to use
-  reg <- sprintf("workers-%s", attr(workers, "name"))
-
+  name <- attr(workers, "name")
+  stopifnot(is.character(name), length(name) == 1L)
+  reg <- sprintf("workers-%s", name)
+  
   usedNodes <- function() {
     ## Number of unresolved cluster futures
     length(FutureRegistry(reg, action="list", earlySignal=FALSE))
   }
 
 
+  t0 <- Sys.time()
+  dt <- 0
   iter <- 1L
   interval <- delta
   finished <- FALSE
-  while (iter <= times) {
-    finished <- (usedNodes() < total)
+  while (dt <= timeout) {
+    ## Check for available nodes
+    used <- usedNodes()
+    finished <- (used < total)
     if (finished) break
 
+    mdebug(sprintf("Poll #%d (%s): usedNodes() = %d, workers = %d", iter, format(round(dt, digits = 2L)), used, total))
+
     ## Wait
     Sys.sleep(interval)
-
+    interval <- alpha*interval
+    
     ## Finish/close workers, iff possible
     await()
 
-    interval <- alpha*interval
     iter <- iter + 1L
+    dt <- difftime(Sys.time(), t0)
   }
 
   if (!finished) {
-    msg <- sprintf("TIMEOUT: All %d workers are still occupied", total)
+    msg <- sprintf("TIMEOUT: All %d cluster nodes are still occupied after %s (polled %d times)", total, format(round(dt, digits = 2L)), iter)
     mdebug(msg)
     stop(msg)
   }
