@@ -1,4 +1,4 @@
-#' Create a cluster future whose value will be resolved asynchroneously in a parallel process
+#' Create a cluster future whose value will be resolved asynchronously in a parallel process
 #'
 #' A cluster future is a future that uses cluster evaluation,
 #' which means that its \emph{value is computed and resolved in
@@ -36,7 +36,7 @@
 #' and \code{\link{\%<-\%}} will create \emph{cluster futures}.
 #'
 #' @export
-cluster <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE, persistent=FALSE, workers=NULL, user=NULL, revtunnel=TRUE, homogeneous=TRUE, gc=FALSE, earlySignal=FALSE, label=NULL, ...) {
+cluster <- function(expr, envir=parent.frame(), substitute=TRUE, lazy=FALSE, seed=NULL, globals=TRUE, persistent=FALSE, workers=availableWorkers(), user=NULL, revtunnel=TRUE, homogeneous=TRUE, gc=FALSE, earlySignal=FALSE, label=NULL, ...) {
   ## BACKWARD COMPATIBILITY
   args <- list(...)
   if ("cluster" %in% names(args)) {
@@ -46,7 +46,10 @@ cluster <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE, p
 
   if (substitute) expr <- substitute(expr)
 
-  future <- ClusterFuture(expr=expr, envir=envir, substitute=FALSE, globals=globals, persistent=persistent, workers=workers, user=user, revtunnel=revtunnel, homogeneous=homogeneous, gc=gc, earlySignal=earlySignal, label=label, ...)
-  run(future)
+  future <- ClusterFuture(expr=expr, envir=envir, substitute=FALSE, lazy=lazy, seed=seed, globals=globals, persistent=persistent, workers=workers, user=user, revtunnel=revtunnel, homogeneous=homogeneous, gc=gc, earlySignal=earlySignal, label=label, ...)
+  if (!future$lazy) future <- run(future)
+  invisible(future)
 }
 class(cluster) <- c("cluster", "multiprocess", "future", "function")
+attr(cluster, "init") <- TRUE
+
