@@ -6,21 +6,30 @@
 #' using \code{\link{plan}()} such that it is evaluated in parallel on,
 #' for instance, the current machine, on a remote machine, or via a
 #' job queue on a compute cluster.
-#' Importantly, \R code using futures remains the same regardless
-#' on these settings.
+#' Importantly, any \R code using futures remains the same regardless
+#' on these settings and there is no need to modify the code when
+#' switching from, say, sequential to parallel processing.
+#'
+#' @param expr,value An \R \link[base]{expression} to be evaluated.
 #'
-#' @param expr An \R \link[base]{expression}.
 #' @param envir The \link{environment} from where global
-#' objects should be identified.  Depending on "evaluator",
-#' it may also be the environment in which the expression
-#' is evaluated.
+#' objects should be identified.  Depending on the future
+#' strategy (the \code{evaluator}), it may also be the environment
+#' in which the expression is evaluated.
+#'
 #' @param substitute If TRUE, argument \code{expr} is
 #' \code{\link[base]{substitute}()}:ed, otherwise not.
+#'
+#' @param lazy Specifies whether a future should be resolved
+#' lazily or eagerly.  The default is eager evaluation
+#' (except when the \emph{deprecated} \code{plan(lazy)} is used).
+#'
+#' @param seed (optional) A L'Ecuyer-CMRG RNG seed.
+#'
 #' @param globals A logical, a character vector,
 #' or a named list for controlling how globals are handled.
 #' For details, see below section.
-#' This argument can be specified via the \dots arguments
-#' for \code{future()} and \code{futureCall()}.
+#'
 #' @param evaluator The actual function that evaluates
 #' the future expression and returns a \link{Future}.
 #' The evaluator function should accept all of the same
@@ -28,22 +37,12 @@
 #' (except \code{evaluator}, \code{FUN} and \code{args}).
 #' The default evaluator function is the one that the user
 #' has specified via \code{\link{plan}()}.
+#'
 #' @param ... Additional arguments passed to the "evaluator".
 #'
 #' @return
 #' \code{f <- future(expr)} creates a \link{Future} \code{f} that evaluates expression \code{expr}, the value of the future is retrieved using \code{v <- value(f)}.
 #'
-#' \code{f <- futureCall(FUN, args)} creates a \link{Future} \code{f} that calls function \code{FUN} with arguments \code{args}, where the value of the future is retrieved using \code{v <- value(f)}.
-#'
-#' \code{futureAssign("v", expr)} and \code{v \%<-\% expr} (a future assignment) create a \link{Future} that evaluates expression \code{expr} and binds its value (as a \link[base]{promise}) to a variable \code{v}.  The value of the future is automatically retrieved when the assigned variable (promise) is queried.
-#' The future itself is returned invisibly, e.g.
-#' \code{f <- futureAssign("v", expr)} and \code{f <- (v \%<-\% expr)}.
-#' Alternatively, the future of a future variable \code{v} can be retrieved
-#' without blocking using \code{f <- \link{futureOf}(v)}.
-#' Both the future and the variable (promise) are assigned to environment
-#' \code{assign.env} where the name of the future is \code{.future_<name>}.
-#'
-#'
 #' @details
 #' The state of a future is either unresolved or resolved.
 #' The value of a future can be retrieved using \code{v <- \link{value}(f)}.
@@ -52,22 +51,42 @@
 #' It is possible to check whether a future is resolved or not
 #' without blocking by using \code{\link{resolved}(f)}.
 #'
-#' For a future created via a future assignment, the value is bound to
-#' a promise, which when queried will internally call \code{\link{value}()}
-#' on the future and which will then be resolved into a regular variable
-#' bound to that value.  For example, with future assignment
-#' \code{v \%<-\% expr}, the first time variable \code{v} is queried
-#' the call blocks if (and only if) the future is not yet resolved. As soon
-#' as it is resolved, and any succeeding queries, querying \code{v} will
-#' immediately give the value.
+#' For a future created via a future assignment
+#' (\code{x \%<-\% value} or \code{futureAssign("x", value)}), the value
+#' is bound to a promise, which when queried will internally call
+#' \code{\link{value}()}  on the future and which will then be resolved
+#' into a regular variable bound to that value.  For example, with future
+#' assignment \code{x \%<-\% value}, the first time variable \code{x} is
+#' queried the call blocks if (and only if) the future is not yet resolved.
+#' As soon as it is resolved, and any succeeding queries, querying \code{x}
+#' will immediately give the value.
 #'
-#' The future assignment construct \code{v \%<-\% expr} is not a formal
-#' assignment per se, but a binary infix operator on objects \code{v}
-#' and \code{expr}.  However, by using non-standard evaluation, this
-#' constructs can emulate an assignment operator similar to
-#' \code{v <- expr}. Due to \R's precedence rules of operators,
-#' future expressions that contain multiple statements need to be
-#' explicitly bracketed, e.g. \code{v \%<-\% { a <- 2; a^2 }}.
+#' The future assignment construct \code{x \%<-\% value} is not a formal
+#' assignment per se, but a binary infix operator on objects \code{x}
+#' and expression \code{value}.  However, by using non-standard evaluation,
+#' this constructs can emulate an assignment operator similar to
+#' \code{x <- value}. Due to \R's precedence rules of operators,
+#' future expressions often needs to be explicitly bracketed, e.g.
+#' \code{x \%<-\% { a + b }}.
+#'
+#'
+#' @section Eager or lazy evaluation:
+#' By default, a future is resolved using \emph{eager} evaluation
+#' (\code{lazy = FALSE}).  This means that the expression starts to
+#' be evaluated as soon as the future is created.
+#'
+#' As an alternative, the future can be resolved using \emph{lazy}
+#' evaluation (\code{lazy = TRUE}).  This means that the expression
+#' will only be evaluated when the value of the future is requested.
+#' \emph{Note that this means that the expression may not be evaluated
+#' at all - it is guaranteed to be evaluated if the value is requested}.
+#'
+#' For future assignments, lazy evaluation can be controlled via the
+#' \code{\%lazy\%} operator, e.g. \code{x \%<-\% { expr } \%lazy\% TRUE}.
+#'
+#' Until deprecated \code{plan(lazy)} is defunct, the default
+#' (\code{lazy = NA}) is eager evaluation \emph{unless} \code{plan(lazy)}
+#' is set.
 #'
 #'
 #' @section Globals used by future expressions:
@@ -116,7 +135,7 @@
 #'
 #' Specifying globals explicitly avoids the overhead added from
 #' automatically identifying the globals and gathering their values.
-#' Futhermore, if we know that the future expression does not make use
+#' Furthermore, if we know that the future expression does not make use
 #' of any global variables, we can disable the automatic search for
 #' globals by using
 #' \preformatted{
@@ -174,20 +193,28 @@
 #'
 #'
 #' @seealso
-#' How, when and where futures are resolved is given by the future strategy,
-#' which can be set by the \code{\link{plan}()} function.
+#' How, when and where futures are resolved is given by the
+#' \emph{future strategy}, which can be set by the end user using the
+#' \code{\link{plan}()} function.  The future strategy must not be
+#' set by the developer, e.g. it must not be called within a package.
 #'
 #' @aliases futureCall
 #' @export
 #' @name future
-future <- function(expr, envir=parent.frame(), substitute=TRUE, evaluator=plan(), ...) {
+future <- function(expr, envir=parent.frame(), substitute=TRUE, lazy=NA, seed=NULL, globals=TRUE, evaluator=plan("next"), ...) {
   if (substitute) expr <- substitute(expr)
 
   if (!is.function(evaluator)) {
     stop("Argument 'evaluator' must be a function: ", typeof(evaluator))
   }
 
-  future <- evaluator(expr, envir=envir, substitute=FALSE, ...)
+  ## BACKWARD COMPATIBILITY: So that plan(lazy) still works
+  ## TODO: Remove when lazy() is removed.
+  if (is.na(lazy)) {
+    future <- evaluator(expr, envir=envir, substitute=FALSE, seed=seed, globals=globals, ...)
+  } else {
+    future <- evaluator(expr, envir=envir, substitute=FALSE, lazy=lazy, seed=seed, globals=globals, ...)
+  }
 
   ## Assert that a future was returned
   if (!inherits(future, "Future")) {
