@@ -1,4 +1,4 @@
-#' Create a multicore future whose value will be resolved asynchroneously in a forked parallel process
+#' Create a multicore future whose value will be resolved asynchronously in a forked parallel process
 #'
 #' A multicore future is a future that uses multicore evaluation,
 #' which means that its \emph{value is computed and resolved in
@@ -12,7 +12,7 @@
 #' @return A \link{MulticoreFuture}
 #' If \code{workers == 1}, then all processing using done in the
 #' current/main R session and we therefore fall back to using
-#' an eager future.  This is also the case whenever multicore
+#' an sequential future.  This is also the case whenever multicore
 #' processing is not supported, e.g. on Windows.
 #'
 #' @example incl/multicore.R
@@ -27,7 +27,7 @@
 #' Not all systems support multicore futures.  For instance,
 #' it is not supported on Microsoft Windows.  Trying to create
 #' multicore futures on non-supported systems will silently
-#' fall back to using \link{eager} futures, which effectively
+#' fall back to using \link{sequential} futures, which effectively
 #' corresponds to a multicore future that can handle one parallel
 #' process (the current one) before blocking.
 #'
@@ -50,7 +50,7 @@
 #' system.
 #'
 #' @export
-multicore <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE, workers=availableCores(constraints="multicore"), earlySignal=FALSE, label=NULL, ...) {
+multicore <- function(expr, envir=parent.frame(), substitute=TRUE, lazy=FALSE, seed=NULL, globals=TRUE, workers=availableCores(constraints="multicore"), earlySignal=FALSE, label=NULL, ...) {
   ## BACKWARD COMPATIBILITY
   args <- list(...)
   if ("maxCores" %in% names(args)) {
@@ -62,19 +62,20 @@ multicore <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE,
   workers <- as.integer(workers)
   stopifnot(is.finite(workers), workers >= 1L)
 
-  ## Fall back to eager uniprocess futures if only a single additional R process
+  ## Fall back to sequential futures if only a single additional R process
   ## can be spawned off, i.e. then use the current main R process.
   ## Uniprocess futures best reflect how multicore futures handle globals.
   if (workers == 1L || !supportsMulticore()) {
     ## covr: skip=1
-    return(uniprocess(expr, envir=envir, substitute=FALSE, globals=globals, local=TRUE, label=label, lazy=FALSE))
+    return(uniprocess(expr, envir=envir, substitute=FALSE, lazy=lazy, seed=seed, globals=globals, local=TRUE, label=label))
   }
 
   oopts <- options(mc.cores=workers)
   on.exit(options(oopts))
 
-  future <- MulticoreFuture(expr=expr, envir=envir, substitute=FALSE, globals=globals, workers=workers, earlySignal=earlySignal, label=label)
-  run(future)
+  future <- MulticoreFuture(expr=expr, envir=envir, substitute=FALSE, lazy=lazy, seed=seed, globals=globals, workers=workers, earlySignal=earlySignal, label=label, ...)
+  if (!future$lazy) future <- run(future)
+  invisible(future)
 }
 class(multicore) <- c("multicore", "multiprocess", "future", "function")
 
@@ -133,11 +134,15 @@ usedCores <- function() {
 #'
 #' @param await A function used to try to "collect"
 #'        finished multicore subprocesses.
+#'
 #' @param workers Total number of workers available.
-#' @param times Then maximum number of times subprocesses
-#'        should be collected before timeout.
+#'
+#' @param timeout Maximum waiting time (in seconds) allowed
+#'        before a timeout error is generated.
+#'
 #' @param delta Then base interval (in seconds) to wait
 #'        between each try.
+#'
 #' @param alpha A multiplicative factor used to increase
 #'        the wait interval after each try.
 #'
@@ -145,11 +150,10 @@ usedCores <- function() {
 #'         extensive waiting, then a timeout error is thrown.
 #'
 #' @keywords internal
-requestCore <- function(await, workers=availableCores(), times=getOption("future.wait.times", 1000), delta=getOption("future.wait.interval", 1.0), alpha=getOption("future.wait.alpha", 1.01)) {
+requestCore <- function(await, workers=availableCores(), timeout = getOption("future.wait.timeout", 30*24*60*60), delta=getOption("future.wait.interval", 0.2), alpha=getOption("future.wait.alpha", 1.01)) {
   stopifnot(length(workers) == 1L, is.numeric(workers), is.finite(workers), workers >= 1)
   stopifnot(is.function(await))
-  times <- as.integer(times)
-  stopifnot(is.finite(times), times > 0)
+  stopifnot(is.finite(timeout), timeout >= 0)
   stopifnot(is.finite(alpha), alpha > 0)
 
   mdebug(sprintf("requestCore(): workers = %d", workers))
@@ -159,31 +163,36 @@ requestCore <- function(await, workers=availableCores(), times=getOption("future
     stop("INTERNAL ERROR: requestCore() was asked to find a free core, but there is only one core available, which is already occupied by the main R process.")
   }
 
+  
+  t0 <- Sys.time()
+  dt <- 0
   iter <- 1L
   interval <- delta
   finished <- FALSE
-  while (iter <= times) {
+  while (dt <= timeout) {
+    ## Check for available cores
     used <- usedCores()
     finished <- (used < workers)
     if (finished) break
 
-    mdebug(sprintf("usedCores() = %d, workers = %d", used, workers))
+    mdebug(sprintf("Poll #%d (%s): usedCores() = %d, workers = %d", iter, format(round(dt, digits = 2L)), used, workers))
 
     ## Wait
     Sys.sleep(interval)
+    interval <- alpha*interval
 
     ## Finish/close cores, iff possible
     await()
 
-    interval <- alpha*interval
     iter <- iter + 1L
+    dt <- difftime(Sys.time(), t0)
   }
 
   if (!finished) {
-    msg <- sprintf("TIMEOUT: All %d CPU cores are still occupied", workers)
+    msg <- sprintf("TIMEOUT: All %d cores are still occupied after %s (polled %d times)", workers, format(round(dt, digits = 2L)), iter)
     mdebug(msg)
     stop(msg)
   }
 
-  invisible(finished)
+  invisible(unname(finished))
 }
