@@ -14,6 +14,16 @@ nbrOfWorkers <- function(evaluator=NULL) {
 }
 
 
+#' @export
+nbrOfWorkers.cluster <- function(evaluator) {
+  expr <- formals(evaluator)$workers
+  workers <- eval(expr)
+  stopifnot(is.character(workers) || is.numeric(workers), !anyNA(workers))
+  if (is.character(workers)) workers <- length(workers)
+  stopifnot(length(workers) == 1, is.finite(workers), workers >= 1)
+  workers
+}
+
 #' @export
 nbrOfWorkers.uniprocess <- function(evaluator) 1L
 
