@@ -22,7 +22,15 @@ values.list <- function(x, ...) {
 
   for (ii in seq_along(y)) {
     tmp <- y[[ii]]
-    if (inherits(tmp, "Future")) y[[ii]] <- value(tmp, ...)
+    if (inherits(tmp, "Future")) {
+      v <- value(tmp, ...)
+      if (is.null(v)) {
+        y[ii] <- list(NULL)
+      } else {
+        y[[ii]] <- v
+        v <- NULL
+      }
+    }
   }
   y
 }
@@ -45,7 +53,15 @@ values.listenv <- function(x, ...) {
   y <- resolve(y)
   for (ii in seq_along(y)) {
     tmp <- y[[ii]]
-    if (inherits(tmp, "Future")) y[[ii]] <- value(tmp, ...)
+    if (inherits(tmp, "Future")) {
+      v <- value(tmp, ...)
+      if (is.null(v)) {
+        y[ii] <- list(NULL)
+      } else {
+        y[[ii]] <- v
+        v <- NULL
+      }
+    }
   }
   y
 }
