@@ -1,13 +1,9 @@
-library("future")
+source("incl/start.R")
 library("listenv")
 
 message("*** futureOf() ...")
 
-ovars <- ls()
-oopts <- options(warn=1)
-plan(lazy)
-
-a %<-% { 1 }
+a %<-% { 1 } %lazy% TRUE
 
 f1 <- futureOf("a")
 print(f1)
@@ -24,8 +20,5 @@ stopifnot(inherits(res, "try-error"))
 
 message("*** futureOf() ... DONE")
 
+source("incl/end.R")
 
-## Cleanup
-plan(eager)
-options(oopts)
-rm(list=setdiff(ls(), ovars))
