@@ -38,6 +38,17 @@ for (strategy in supportedStrategies()) {
   print(y)
   stopifnot(all.equal(y, v0))
 
+  attachLocally(globals)
+  f <- futureAssign("y", {
+    x <- 1:10
+    sumtwo(a + b*x)
+  }, globals=TRUE)
+  print(f)
+  rm(list=names(globals))
+  z <- value(f)
+  print(z)
+  stopifnot(all.equal(z, y), all.equal(y, v0))
+  
   attachLocally(globals)
   y %<-% {
     x <- 1:10
@@ -47,11 +58,48 @@ for (strategy in supportedStrategies()) {
   print(y)
   stopifnot(all.equal(y, v0))
 
+  attachLocally(globals)
+  f <- future({
+    x <- 1:10
+    sumtwo(a + b*x)
+  }, lazy=TRUE, globals=TRUE)
+  print(f)
+  rm(list=names(globals))
+  y <- value(f)
+  print(y)
+  stopifnot(all.equal(y, v0))
+
+  attachLocally(globals)
+  f <- futureAssign("y", {
+    x <- 1:10
+    sumtwo(a + b*x)
+  }, lazy=TRUE, globals=TRUE)
+  print(f)
+  rm(list=names(globals))
+  z <- value(f)
+  print(z)
+  stopifnot(all.equal(z, y), all.equal(y, v0))
+
+  ## Same with lazy evaluation
+  attachLocally(globals)
+  y %<-% {
+    x <- 1:10
+    sumtwo(a + b*x)
+  } %lazy% TRUE %globals% TRUE
+  rm(list=names(globals))
+  print(y)
+  stopifnot(all.equal(y, v0))
+
   ## No need to search for globals
   y %<-% { 1 } %globals% FALSE
   print(y)
   stopifnot(identical(y, 1))
 
+  ## Same with lazy evaluation
+  y %<-% { 1 } %lazy% TRUE %globals% FALSE
+  print(y)
+  stopifnot(identical(y, 1))
+
   ## Exception - missing global
   attachLocally(globals)
   f <- future({
@@ -90,6 +138,15 @@ for (strategy in supportedStrategies()) {
   print(v)
   stopifnot(all.equal(v, v0))
 
+  f <- future({
+    x <- 1:10
+    sumtwo(a + b*x)
+  }, lazy=TRUE, globals=globals)
+  print(f)
+  v <- value(f)
+  print(v)
+  stopifnot(all.equal(v, v0))
+
   y %<-% {
     x <- 1:10
     sumtwo(a + b*x)
@@ -97,6 +154,13 @@ for (strategy in supportedStrategies()) {
   print(y)
   stopifnot(all.equal(y, v0))
 
+  y %<-% {
+    x <- 1:10
+    sumtwo(a + b*x)
+  } %lazy% TRUE %globals% globals
+  print(y)
+  stopifnot(all.equal(y, v0))
+
   message(sprintf("- Strategy: %s ... DONE", strategy))
 }
 
@@ -121,6 +185,17 @@ for (strategy in supportedStrategies()) {
   print(v)
   stopifnot(all.equal(v, v0))
 
+  attachLocally(globals)
+  f <- future({
+    x <- 1:10
+    sumtwo(a + b*x)
+  }, lazy=TRUE, globals=c("a", "b", "sumtwo"))
+  print(f)
+  rm(list=names(globals))
+  v <- value(f)
+  print(v)
+  stopifnot(all.equal(v, v0))
+
   attachLocally(globals)
   y %<-% {
     x <- 1:10
@@ -130,6 +205,15 @@ for (strategy in supportedStrategies()) {
   print(y)
   stopifnot(all.equal(y, v0))
 
+  attachLocally(globals)
+  y %<-% {
+    x <- 1:10
+    sumtwo(a + b*x)
+  } %lazy% TRUE %globals% c("a", "b", "sumtwo")
+  rm(list=names(globals))
+  print(y)
+  stopifnot(all.equal(y, v0))
+
   message(sprintf("- Strategy: %s ... DONE", strategy))
 }
 
