@@ -2,11 +2,32 @@
 ovars <- ls()
 oenvs <- oenvs0 <- Sys.getenv()
 oopts0 <- options()
+
+## Default options
 oopts <- options(
   warn=1L,
   mc.cores=2L,
-  future.debug=TRUE
+  future.debug=TRUE,
+  ## Reset the following during testing in case
+  ## they are set on the test system
+  future.availableCores.system=NULL,
+  future.availableCores.fallback=NULL
 )
+
+
+## Reset the following during testing in case
+## they are set on the test system
+oenvs2 <- Sys.unsetenv(c(
+  "R_FUTURE_AVAILABLECORES_SYSTEM",
+  "R_FUTURE_AVAILABLECORES_FALLBACK",
+  ## SGE
+  "NSLOTS", "PE_HOSTFILE",
+  ## Slurm
+  "SLURM_CPUS_PER_TASK",
+  ## TORQUE / PBS
+  "PBS_NUM_PPN", "PBS_NODEFILE", "PBS_NP", "PBS_NUM_NODES"
+))
+
 oplan <- future::plan()
 
 ## Use eager futures by default
@@ -20,7 +41,7 @@ ClusterRegistry <- future:::ClusterRegistry
 constant <- future:::constant
 uniprocess <- future:::uniprocess ## To become public
 detectCores <- future:::detectCores
-flapply <- future:::flapply
+future_lapply <- future:::future_lapply
 FutureRegistry <- future:::FutureRegistry
 gassign <- future:::gassign
 get_future <- future:::get_future
@@ -38,6 +59,7 @@ requirePackages <- future:::requirePackages
 supportedStrategies <- future:::supportedStrategies
 tweakExpression <- future:::tweakExpression
 whichIndex <- future:::whichIndex
+    
 
 ## Local functions for test scripts
 printf <- function(...) cat(sprintf(...))
