@@ -2,7 +2,7 @@ source("incl/start.R")
 
 message("*** nbrOfWorkers() ...")
 
-strategies <- c("uniprocess", "transparent", "eager", "lazy")
+strategies <- c("sequential", "transparent", "eager", "lazy")
 for (strategy in strategies) {
   message("Type of future: ", strategy)
 
@@ -18,10 +18,13 @@ for (strategy in strategies) {
 } ## for (strategy ...)
 
 
-strategies <- c("multiprocess", "multisession", "multicore")
+strategies <- c("cluster", "multiprocess", "multisession", "multicore")
 strategies <- intersect(strategies, supportedStrategies())
 cores <- availableCores()
 message("Number of available cores: ", cores)
+workers <- availableWorkers()
+nworkers <- length(workers)
+message(sprintf("Available workers: [n=%d] %s", nworkers, hpaste(sQuote(workers))))
 
 for (strategy in strategies) {
   message("Type of future: ", strategy)
@@ -29,15 +32,22 @@ for (strategy in strategies) {
   evaluator <- get(strategy, mode="function")
   n <- nbrOfWorkers(evaluator)
   message(sprintf("nbrOfWorkers: %d", n))
-  stopifnot(n == cores)
+  stopifnot(n == nworkers)
 
   plan(strategy)
   n <- nbrOfWorkers()
   message(sprintf("nbrOfWorkers: %d", n))
-  stopifnot(n == cores)
+  stopifnot(n == nworkers)
 } ## for (strategy ...)
 
 
+message("Type of future: cluster")
+workers <- rep("localhost", times = 2L)
+plan(cluster, workers = workers)
+n <- nbrOfWorkers()
+message(sprintf("nbrOfWorkers: %d", n))
+stopifnot(n == length(workers))
+
 message("Type of future: constant")
 n <- nbrOfWorkers(constant)
 message(sprintf("nbrOfWorkers: %d", n))
