@@ -2,26 +2,26 @@ source("incl/start,load-only.R")
 
 message("*** plan() ...")
 
-message("*** Set strategy via future::plan(future::lazy)")
-oplan <- future::plan(future::lazy)
+message("*** Set strategy via future::plan(future::multisession)")
+oplan <- future::plan(future::multisession)
 print(future::plan())
 future::plan(oplan)
 print(future::plan())
 
-message("*** Set strategy via future::plan(future::lazy, local=FALSE)")
-oplan <- future::plan(future::lazy, local=FALSE)
+message("*** Set strategy via future::plan(future::multisession, globals=FALSE)")
+oplan <- future::plan(future::multisession, globals=FALSE)
 print(future::plan())
 future::plan(oplan)
 print(future::plan())
 
-message("*** Set strategy via future::plan(future::lazy(local=FALSE)")
-oplan <- future::plan(future::lazy(local=FALSE))
+message("*** Set strategy via future::plan(future::multisession(globals=FALSE)")
+oplan <- future::plan(future::multisession(globals=FALSE))
 print(future::plan())
 future::plan(oplan)
 print(future::plan())
 
-message("*** Set strategy via future::plan('lazy')")
-oplan <- future::plan("lazy")
+message("*** Set strategy via future::plan('multisession')")
+oplan <- future::plan("multisession")
 print(future::plan())
 future::plan(oplan)
 print(future::plan())
@@ -40,7 +40,7 @@ res <- try(plan('unknown strategy'), silent=TRUE)
 print(res)
 stopifnot(inherits(res, "try-error"))
 
-message("*** plan() by (lazy) function")
+message("*** plan() by (lazy) function [DEPRECATED]")
 
 ## Setting strategy by function
 plan(lazy)
@@ -49,7 +49,7 @@ f <- future({
   b <- 3
   c <- 2
   a * b * c
-})
+}, lazy = TRUE)
 a <- 7  ## Make sure globals are frozen
 ##if ("covr" %in% loadedNamespaces()) v <- 0 else ## WORKAROUND
 v <- value(f)
@@ -57,8 +57,8 @@ print(v)
 stopifnot(v == 0)
 
 
-message("*** plan(uniprocess)")
-plan(uniprocess)
+message("*** plan(sequential)")
+plan(sequential)
 a <- 0
 f <- future({
   b <- 3
@@ -71,15 +71,15 @@ print(v)
 stopifnot(v == 0)
 
 
-message("*** plan('uniprocess')")
+message("*** plan('sequential')")
 ## Setting strategy by name
-plan("lazy")
+plan("multisession")
 print(plan())
 
 
 message("*** plan() and overriding defaults")
-message("*** plan(uniprocess)")
-plan(uniprocess)
+message("*** plan(sequential)")
+plan(sequential)
 fcn <- plan()
 print(fcn)
 stopifnot(formals(fcn)$local == TRUE)
@@ -88,8 +88,8 @@ f <- future({ x <- 1 })
 print(value(f))
 stopifnot(x == 0)
 
-message("*** plan(uniprocess, local=FALSE)")
-plan(uniprocess, local=FALSE)
+message("*** plan(sequential, local=FALSE)")
+plan(sequential, local=FALSE)
 fcn <- plan()
 print(fcn)
 stopifnot(formals(fcn)$local == FALSE)
@@ -98,22 +98,22 @@ f <- future({ x <- 1 })
 print(value(f))
 stopifnot(x == 1)
 
-message("*** plan(uniprocess, local=FALSE, abc=1, def=TRUE)")
-plan(uniprocess, local=FALSE, abc=1, def=TRUE)
+message("*** plan(sequential, local=FALSE, abc=1, def=TRUE)")
+plan(sequential, local=FALSE, abc=1, def=TRUE)
 fcn <- plan()
 print(fcn)
 stopifnot(formals(fcn)$local == FALSE)
 
-message("*** plan(uniprocess(local=FALSE))")
-plan(lazy)
-plan(uniprocess(local=FALSE))
+message("*** plan(sequential(local=FALSE))")
+plan(multisession)
+plan(sequential(local=FALSE))
 fcn <- plan()
 print(fcn)
 stopifnot(formals(fcn)$local == FALSE)
 
-message("*** plan(tweak(uniprocess, local=FALSE))")
-plan(lazy)
-plan(tweak(uniprocess, local=FALSE))
+message("*** plan(tweak(sequential, local=FALSE))")
+plan(multisession)
+plan(tweak(sequential, local=FALSE))
 fcn <- plan()
 print(fcn)
 stopifnot(formals(fcn)$local == FALSE)
@@ -121,10 +121,10 @@ stopifnot(formals(fcn)$local == FALSE)
 
 message("*** old <- plan(new)")
 truth <- plan()
-old <- plan(lazy, local=FALSE)
+old <- plan(multisession, globals=FALSE)
 stopifnot(identical(unclass(old), unclass(truth)))
 
-curr <- plan()    ## curr == lazy(local=FALSE)
+curr <- plan()    ## curr == multisession(globals=FALSE)
 prev <- plan(old) ## prev == lazy(local=FALSE)
 stopifnot(identical(unclass(curr), unclass(prev)))
 
@@ -132,40 +132,40 @@ curr <- plan()    ## curr == old
 stopifnot(identical(unclass(curr), unclass(old)))
 stopifnot(identical(unclass(curr), unclass(truth)))
 
-message("*** %plan% 'uniprocess'")
-plan(lazy)
-x %<-% { a <- 1 } %plan% "uniprocess"
-stopifnot(identical(body(plan()), body(lazy)))
+message("*** %plan% 'sequential'")
+plan(multisession)
+x %<-% { a <- 1 } %plan% "sequential"
+stopifnot(identical(body(plan()), body(multisession)))
 
-message("*** %plan% uniprocess")
-plan(lazy)
+message("*** %plan% sequential")
+plan(multisession)
 
 ## %plan% can operate on any expression, so it
 ## works just as an withPlan({ ... }, plan=...)
-fun <- { plan() } %plan% uniprocess
+fun <- { plan() } %plan% sequential
 f <- fun(1)
-stopifnot(inherits(f, "UniprocessFuture"), !f$lazy, inherits(f, "UniprocessFuture"))
+stopifnot(inherits(f, "SequentialFuture"), !f$lazy, inherits(f, "SequentialFuture"))
 
-x %<-% { a <- 1 } %plan% uniprocess
-stopifnot(identical(body(plan()), body(lazy)))
+x %<-% { a <- 1 } %plan% sequential
+stopifnot(identical(body(plan()), body(multisession)))
 
-message("*** %plan% uniprocess(local=FALSE) ")
-plan(lazy)
+message("*** %plan% sequential(local=FALSE) ")
+plan(multisession)
 a <- 0
-x %<-% { a } %plan% uniprocess(local=FALSE)
+x %<-% { a } %plan% sequential(local=FALSE)
 a <- 42
 print(x)
 stopifnot(x == 0)
-stopifnot(identical(body(plan()), body(lazy)))
+stopifnot(identical(body(plan()), body(multisession)))
 
-message("*** Nested futures with different plans ")
+message("*** Nested futures with different plans [DEPRECATED]")
 plan(lazy)
 c %<-% {
   message("Resolving 'c'")
   a %<-% {
     message("Resolving 'a'")
     2
-  } %plan% uniprocess
+  } %plan% sequential
   b %<-% {
     message("Resolving 'b'")
     -9 * a
@@ -173,7 +173,7 @@ c %<-% {
   message("Local variable 'x'")
   x <- b / 3
   abs(x)
-}
+} %lazy% TRUE
 d <- 42
 print(d)
 print(c)
@@ -181,35 +181,35 @@ stopifnot(c == 6)
 
 message("*** plan() by functions and character names ... ")
 
-plan(uniprocess)
+plan(sequential)
 a %<-% 42
 stopifnot(a == 42)
 
-plan("uniprocess")
+plan("sequential")
 a %<-% 42
 stopifnot(a == 42)
 
-plan(list(uniprocess))
+plan(list(sequential))
 a %<-% 42
 stopifnot(a == 42)
 
-plan(list("uniprocess"))
+plan(list("sequential"))
 a %<-% 42
 stopifnot(a == 42)
 
-plan(list(uniprocess, lazy))
+plan(list(sequential, sequential))
 a %<-% { b %<-% 42; b }
 stopifnot(a == 42)
 
-plan(list("uniprocess", lazy))
+plan(list("sequential", sequential))
 a %<-% { b %<-% 42; b }
 stopifnot(a == 42)
 
-plan(list(uniprocess, "lazy"))
+plan(list(sequential, "sequential"))
 a %<-% { b %<-% 42; b }
 stopifnot(a == 42)
 
-plan(list("uniprocess", "lazy"))
+plan(list("sequential", "sequential"))
 a %<-% { b %<-% 42; b }
 stopifnot(a == 42)
 
@@ -218,7 +218,7 @@ message("*** plan() by functions and character names ... DONE")
 
 message("*** plan() w/ commands ...")
 
-plan(list(uniprocess, uniprocess))
+plan(list(sequential, sequential))
 res <- plan("list")
 print(res)
 stopifnot(length(res) == 2)
